@@ -32,6 +32,19 @@ class ImagePipeline(OPipeline[OlympImage]):
         if data is not None:
             self.pipeline = Pipeline(data)
 
+    @staticmethod
+    def load_paths(
+        paths: List[str],
+        metadata_function: Optional[Callable[[str], Any]] = None,
+    ) -> "ImagePipeline":
+        data = [OlympImage(p) for p in paths]
+
+        if metadata_function is not None:
+            for d in data:
+                d.metadata = metadata_function(d.path)
+
+        return ImagePipeline(data)
+
     @staticmethod
     def load_folder(
         path: str,
@@ -105,11 +118,21 @@ class ImagePipeline(OPipeline[OlympImage]):
 
     def task_path(self, func: Callable[[str], str], count: int = 1) -> "ImagePipeline":
         def r(o: OlympImage) -> OlympImage:
+            o.ensure_load()
             o.path = func(o.path)
             return o
 
         return self.task(r, count)
 
+    def explode(self, explode_function: Callable[[OlympImage], List[OlympImage]]):
+        if self.pipeline is None:
+            raise Exception("No defined pipeline")
+
+        output = ImagePipeline()
+        output.pipeline = self.pipeline.explode(explode_function)
+
+        return output
+
     def rescale(
         self,
         size: Tuple[float, float],
@@ -157,6 +180,15 @@ class ImagePipeline(OPipeline[OlympImage]):
 
         return self.task_img(r)
 
+    def filter(self, filter_function: Callable[[OlympImage], bool]) -> "ImagePipeline":
+        if self.pipeline is None:
+            raise Exception("No defined pipeline")
+
+        output = ImagePipeline()
+        output.pipeline = self.pipeline.filter(filter_function)
+
+        return output
+
     def keep_each_frame_in(
         self, keep_n: int = 1, discard_n: int = 0
     ) -> "ImagePipeline":
@@ -253,22 +285,26 @@ class ImagePipeline(OPipeline[OlympImage]):
         return self.task(p)
 
     def draw_relative_bboxes(
-        self, bbox_function: Callable[[OlympImage], List[Tuple[BBoxRelative, Color]]]
+        self,
+        bbox_function: Callable[[OlympImage], List[Tuple[BBoxRelative, Color]]],
+        font_scale: float = ImTools.font_scale,
     ) -> "ImagePipeline":
         def p(o: "OlympImage") -> "OlympImage":
             outputs = bbox_function(o)
             for polygon, color in outputs:
-                o.img = ImTools.draw_relative_bbox(o.img, polygon, color)
+                o.img = ImTools.draw_relative_bbox(o.img, polygon, color, font_scale)
             return o
 
         return self.task(p)
 
     def draw_bboxes(
-        self, bbox_function: Callable[[OlympImage], List[Tuple[BBoxAbsolute, Color]]]
+        self,
+        bbox_function: Callable[[OlympImage], List[Tuple[BBoxAbsolute, Color]]],
+        font_scale: float = ImTools.font_scale,
     ) -> "ImagePipeline":
         def p(o: "OlympImage") -> "OlympImage":
             for polygon, color in bbox_function(o):
-                o.img = ImTools.draw_bbox(o.img, polygon, color)
+                o.img = ImTools.draw_bbox(o.img, polygon, color, font_scale)
             return o
 
         return self.task(p)
